.. QRangeSlider documentation master file, created by
   sphinx-quickstart on Thu Apr 28 01:01:11 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===============================
QRangeSlider v0.1 documentation
===============================

The QRangeSlider class implements a horizontal PyQt range slider widget.

Examples
========

.. image:: ../data/example1.png
   :align: center

.. image:: ../data/example2.png
   :align: center

.. image:: ../data/example3.png
   :align: center

API Reference
=============

.. toctree::
   :maxdepth: 2

.. automodule:: qrangeslider
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

